@@ -31,23 +31,24 @@
 #include "gtksourcegutterrenderer-private.h"
 
 /**
- * GtkSourceGutter:
+ * SECTION:gutter
+ * @Short_description: Gutter object for GtkSourceView
+ * @Title: GtkSourceGutter
+ * @See_also: #GtkSourceView, #GtkSourceMark
  *
- * Gutter object for [class@View].
- *
- * The `GtkSourceGutter` object represents the left or right gutter of the text
- * view. It is used by [class@View] to draw the line numbers and
- * [class@Mark]s that might be present on a line. By packing
- * additional [class@GutterRenderer] objects in the gutter, you can extend the
+ * The #GtkSourceGutter object represents the left or right gutter of the text
+ * view. It is used by #GtkSourceView to draw the line numbers and
+ * #GtkSourceMark<!-- -->s that might be present on a line. By packing
+ * additional #GtkSourceGutterRenderer objects in the gutter, you can extend the
  * gutter with your own custom drawings.
  *
- * To get a `GtkSourceGutter`, use the [method@View.get_gutter] function.
+ * To get a #GtkSourceGutter, use the gtk_source_view_get_gutter() function.
  *
- * The gutter works very much the same way as cells rendered in a [class@Gtk.TreeView].
+ * The gutter works very much the same way as cells rendered in a #GtkTreeView.
  * The concept is similar, with the exception that the gutter does not have an
- * underlying [iface@Gtk.TreeModel]. The builtin line number renderer is at position
- * %GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
- * %GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). The gutter sorts the renderers
+ * underlying #GtkTreeModel. The builtin line number renderer is at position
+ * #GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
+ * #GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). The gutter sorts the renderers
  * in ascending order, from left to right. So the marks are displayed on the
  * right of the line numbers.
  */
@@ -80,11 +81,7 @@ struct _GtkSourceGutter
 	GtkTextWindowType     window_type;
 	GtkOrientation        orientation;
 
-	double                pointer_x;
-	double                pointer_y;
-
 	guint                 is_drawing : 1;
-	guint                 pointer_in_gutter : 1;
 };
 
 G_DEFINE_TYPE (GtkSourceGutter, gtk_source_gutter, GTK_TYPE_WIDGET)
@@ -324,60 +321,10 @@ gtk_source_gutter_measure (GtkWidget      *widget,
 }
 
 static void
-gtk_source_gutter_motion_cb (GtkSourceGutter          *gutter,
-			     double                    x,
-			     double                    y,
-			     GtkEventControllerMotion *motion)
-{
-	g_assert (GTK_SOURCE_IS_GUTTER (gutter));
-	g_assert (GTK_IS_EVENT_CONTROLLER_MOTION (motion));
-
-	gutter->pointer_x = x;
-	gutter->pointer_y = y;
-	gutter->pointer_in_gutter = TRUE;
-
-	_gtk_source_gutter_queue_draw (gutter);
-}
-
-static void
-gtk_source_gutter_leave_cb (GtkSourceGutter          *gutter,
-			    GtkEventControllerMotion *motion)
-{
-	g_assert (GTK_SOURCE_IS_GUTTER (gutter));
-	g_assert (GTK_IS_EVENT_CONTROLLER_MOTION (motion));
-
-	gutter->pointer_x = -1;
-	gutter->pointer_y = -1;
-	gutter->pointer_in_gutter = FALSE;
-
-	_gtk_source_gutter_queue_draw (gutter);
-}
-
-static void
-gtk_source_gutter_root (GtkWidget *widget)
-{
-	GtkWidget *parent;
-
-	g_assert (GTK_SOURCE_IS_GUTTER (widget));
-
-	GTK_WIDGET_CLASS (gtk_source_gutter_parent_class)->root (widget);
-
-	parent = gtk_widget_get_parent (widget);
-
-	/* The GtkTextViewChild has "overflow" set to Hidden and we
-	 * want to allow drawing over that.
-	 */
-	if (parent != NULL)
-	{
-		gtk_widget_set_overflow (parent, GTK_OVERFLOW_VISIBLE);
-	}
-}
-
-static void
-gtk_source_gutter_set_property (GObject      *object,
-                                guint         prop_id,
-                                const GValue *value,
-                                GParamSpec   *pspec)
+gtk_source_gutter_set_property (GObject       *object,
+                                guint          prop_id,
+                                const GValue  *value,
+                                GParamSpec    *pspec)
 {
 	GtkSourceGutter *gutter = GTK_SOURCE_GUTTER (object);
 
@@ -448,7 +395,6 @@ gtk_source_gutter_class_init (GtkSourceGutterClass *klass)
 	widget_class->measure = gtk_source_gutter_measure;
 	widget_class->size_allocate = gtk_source_gutter_size_allocate;
 	widget_class->snapshot = gtk_source_gutter_snapshot;
-	widget_class->root = gtk_source_gutter_root;
 
 	/**
 	 * GtkSourceGutter:view:
@@ -512,15 +458,15 @@ gtk_source_gutter_init (GtkSourceGutter *gutter)
 	motion = gtk_event_controller_motion_new ();
 	g_signal_connect_swapped (motion,
 	                          "enter",
-	                          G_CALLBACK (gtk_source_gutter_motion_cb),
+	                          G_CALLBACK (gtk_widget_queue_draw),
 	                          gutter);
 	g_signal_connect_swapped (motion,
 	                          "leave",
-	                          G_CALLBACK (gtk_source_gutter_leave_cb),
+	                          G_CALLBACK (gtk_widget_queue_draw),
 	                          gutter);
 	g_signal_connect_swapped (motion,
 	                          "motion",
-	                          G_CALLBACK (gtk_source_gutter_motion_cb),
+	                          G_CALLBACK (gtk_widget_queue_draw),
 	                          gutter);
 	gtk_widget_add_controller (GTK_WIDGET (gutter), motion);
 }
@@ -569,6 +515,8 @@ _gtk_source_gutter_new (GtkTextWindowType  type,
  * @gutter: a #GtkSourceGutter.
  *
  * Returns: (transfer none): the associated #GtkSourceView.
+ *
+ * Since: 3.24
  */
 GtkSourceView *
 gtk_source_gutter_get_view (GtkSourceGutter *gutter)
@@ -589,6 +537,9 @@ gtk_source_gutter_get_view (GtkSourceGutter *gutter)
  * @renderer cannot be already inserted to another gutter.
  *
  * Returns: %TRUE if operation succeeded. Otherwise %FALSE.
+ *
+ * Since: 3.0
+ *
  **/
 gboolean
 gtk_source_gutter_insert (GtkSourceGutter         *gutter,
@@ -686,6 +637,8 @@ gtk_source_gutter_remove (GtkSourceGutter         *gutter,
  * @position: the new renderer position.
  *
  * Reorders @renderer in @gutter to new @position.
+ *
+ * Since: 2.8
  */
 void
 gtk_source_gutter_reorder (GtkSourceGutter         *gutter,
@@ -753,14 +706,12 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 {
 	GtkSourceGutter *gutter = GTK_SOURCE_GUTTER (widget);
 	GtkTextView *text_view = GTK_TEXT_VIEW (gutter->view);
-	GtkTextBuffer *buffer;
 	const GList *list;
 	GdkRectangle visible_rect;
-	GtkTextIter begin, end;
-	GtkTextIter cur, sel;
+	GtkTextIter begin;
+	GtkTextIter end;
 	gboolean needs_wrap_first = FALSE;
 	gboolean needs_wrap_last = FALSE;
-	int clip_width = 0;
 
 	g_clear_object (&gutter->lines);
 
@@ -769,8 +720,6 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		return;
 	}
 
-	buffer = gtk_text_view_get_buffer (text_view);
-
 	gtk_text_view_get_visible_rect (text_view, &visible_rect);
 	gtk_text_view_get_iter_at_location (text_view, &begin,
 	                                    visible_rect.x, visible_rect.y);
@@ -778,14 +727,6 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 	                                    visible_rect.x,
 	                                    visible_rect.y + visible_rect.height);
 
-	/* Try to include an extra line on each edge so that situations
-	 * that are dependent on neighboring lines can still include enough
-	 * information to draw correctly. This is useful for situations like
-	 * git where you might need to draw special delete marks.
-	 */
-	gtk_text_iter_backward_line (&begin);
-	gtk_text_iter_forward_line (&end);
-
 	/* The first step is to get line information about all the visible
 	 * lines. We do this up front so that we can do it once to reduce many
 	 * times the renderers need to walk through the buffer contents as that
@@ -798,43 +739,19 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 	                                              needs_wrap_first,
 	                                              needs_wrap_last);
 
-	/* Get the line under the pointer so we can set "prelit" on it */
-	if (gutter->pointer_in_gutter)
-	{
-		GtkTextIter pointer;
-		GdkRectangle pointer_rect;
-
-		gtk_text_view_get_iter_at_location (text_view,
-		                                    &pointer,
-		                                    0,
-		                                    visible_rect.y + gutter->pointer_y);
-		gtk_text_view_get_iter_location (text_view, &pointer, &pointer_rect);
-		pointer_rect.y -= visible_rect.y;
-
-		if (gutter->pointer_y >= pointer_rect.y &&
-		    gutter->pointer_y <= pointer_rect.y + pointer_rect.height)
-		{
-			guint line = gtk_text_iter_get_line (&pointer);
-			gtk_source_gutter_lines_add_class (gutter->lines, line, "prelit");
-		}
-	}
-
 	/* Draw the current-line highlight if necessary */
-	if (gtk_source_view_get_highlight_current_line (gutter->view) &&
-	    !gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel))
+	if (gtk_source_view_get_highlight_current_line (gutter->view))
 	{
-		GdkRGBA highlight;
 		guint cursor_line;
 
 		cursor_line = _gtk_source_gutter_lines_get_cursor_line (gutter->lines);
 
 		if (cursor_line >= gtk_source_gutter_lines_get_first (gutter->lines) &&
-		    cursor_line <= gtk_source_gutter_lines_get_last (gutter->lines) &&
-		    _gtk_source_view_get_current_line_number_background (gutter->view, &highlight))
+		    cursor_line <= gtk_source_gutter_lines_get_last (gutter->lines))
 		{
-			int width = gtk_widget_get_width (widget);
-			int height;
-			int y;
+			GdkRGBA highlight;
+			gint y;
+			gint height;
 
 			gtk_source_gutter_lines_get_line_yrange (gutter->lines,
 			                                         cursor_line,
@@ -842,9 +759,14 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 			                                         &y,
 			                                         &height);
 
-			gtk_snapshot_append_color (snapshot,
-			                           &highlight,
-			                           &GRAPHENE_RECT_INIT (0, y, width, height));
+			if (_gtk_source_view_get_current_line_number_background (gutter->view, &highlight))
+			{
+				int width = gtk_widget_get_width (widget);
+
+				gtk_snapshot_append_color (snapshot,
+				                           &highlight,
+				                           &GRAPHENE_RECT_INIT (0, y, width, height));
+			}
 		}
 	}
 
@@ -867,18 +789,10 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		                                   gutter->lines);
 	}
 
-	clip_width = gtk_widget_get_width (widget);
-
-	/* Allow drawing over the left margin from renderers */
-	if (gutter->window_type == GTK_TEXT_WINDOW_LEFT)
-	{
-		clip_width += gtk_text_view_get_left_margin (text_view);
-	}
-
 	gtk_snapshot_push_clip (snapshot,
 	                        &GRAPHENE_RECT_INIT (0,
 	                                             0,
-						     clip_width,
+	                                             gtk_widget_get_width (widget),
 	                                             gtk_widget_get_height (widget)));
 
 	/* Now let the renderers draw the content for each line. Because
