@@ -1,9 +1,8 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- * gtksourceregion.c - GtkTextMark-based region utility
+/*
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2002 Gustavo Giráldez <gustavo.giraldez@gmx.net>
- * Copyright (C) 2016 Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2002 Gustavo Giráldez <gustavo.giraldez@gmx.net>
+ * Copyright 2016 Sébastien Wilmet <swilmet@gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,9 +18,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "gtksourceregion.h"
 
@@ -671,7 +668,7 @@ gtk_source_region_subtract_subregion (GtkSourceRegion   *region,
 							       FALSE);
 
 			/* No further processing needed. */
-			DEBUG (g_message ("subregion splitted"));
+			DEBUG (g_message ("subregion split"));
 
 			return;
 		}
